===========
scikit-nano
===========

*scikit-nano* is a python toolkit for nano-science.
Currently, its primary use is for generating nano-structure data for the
following nano-materials:

    * Graphene, both single layer graphene and N-layer graphene.
    * Single-walled nanotubes (SWNTs), both single SWNTs and SWNT bundles.
    * Multi-walled nanotubes (MWNTs), both single MWNTs and MWNT bundles.

It supports saving structure data in the following formats:

    * `xyz`
    * LAMMPS `data`

For documentation, visit:
`scikit-nano documentation <http://projects.geekspin.net/scikit-nano/doc>`_
